@@ -3,6 +3,7 @@
  * Copyright (C) 2010 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
  * Copyright (C) 2016-2023 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2023-2024 Hiroyuki Tanaka, Sunil Bhat
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +40,7 @@
 #include "remmina_public.h"
 #include "remmina_pref.h"
 #include "remmina_log.h"
-#include "remmina_stats.h"
+#include "remmina_info.h"
 #include "remmina/remmina_trace_calls.h"
 
 gboolean logstart;
@@ -73,7 +74,7 @@ void remmina_log_stats()
 	TRACE_CALL(__func__);
 	JsonNode *n;
 
-	n = remmina_stats_get_all();
+	n = remmina_info_stats_get_all();
 	if (n != NULL) {
 
 		JsonGenerator *g = json_generator_new();
@@ -203,6 +204,20 @@ void remmina_log_print(const gchar *text)
 	IDLE_ADD(remmina_log_print_real, g_strdup(text));
 }
 
+void remmina_log_file_append(gchar *text) {
+	gchar *log_filename = g_build_filename(g_get_tmp_dir(), LOG_FILE_NAME, NULL);
+	FILE *log_file = fopen(log_filename, "a");
+	g_free(log_filename);
+	
+	if (log_file != NULL)
+	{
+		gchar* text_log = g_strconcat(text, "\n", NULL);
+		fwrite(text_log, sizeof(char), strlen(text_log), log_file);
+		fclose(log_file);
+		g_free(text_log);
+	}
+}
+
 void _remmina_info(const gchar *fmt, ...)
 {
 	TRACE_CALL(__func__);
@@ -213,6 +228,9 @@ void _remmina_info(const gchar *fmt, ...)
 	text = g_strdup_vprintf(fmt, args);
 	va_end(args);
 
+	// Append text to remmina_log_file.log
+	remmina_log_file_append(text);
+
 	// always appends newline
 	g_info ("%s", text);
 
@@ -237,6 +255,9 @@ void _remmina_message(const gchar *fmt, ...)
 	text = g_strdup_vprintf(fmt, args);
 	va_end(args);
 
+	// Append text to remmina_log_file.log
+	remmina_log_file_append(text);
+
 	// always appends newline
 	g_message ("%s", text);
 
@@ -253,7 +274,7 @@ void _remmina_message(const gchar *fmt, ...)
 
 /**
  * Print a string in the Remmina Debug Windows and in the terminal.
- * The string will be visible in the terminal if G_MESSAGES_DEBUG=all
+ * The string will be visible in the terminal if G_MESSAGES_DEBUG=remmina
  * Variadic function of REMMINA_DEBUG
  */
 void _remmina_debug(const gchar *fun, const gchar *fmt, ...)
@@ -266,6 +287,9 @@ void _remmina_debug(const gchar *fun, const gchar *fmt, ...)
 	text = g_strdup_vprintf(fmt, args);
 	va_end(args);
 
+	// Append text to remmina_log_file.log
+	remmina_log_file_append(text);
+
 	g_autofree gchar *buf = g_strconcat("(", fun, ") - ", text, NULL);
 	g_free(text);
 
@@ -293,6 +317,9 @@ void _remmina_warning(const gchar *fun, const gchar *fmt, ...)
 	text = g_strdup_vprintf(fmt, args);
 	va_end(args);
 
+	// Append text to remmina_log_file.log
+	remmina_log_file_append(text);
+
 	g_autofree gchar *buf = g_strconcat("(", fun, ") - ", text, NULL);
 	g_free(text);
 
@@ -318,6 +345,9 @@ void _remmina_audit(const gchar *fun, const gchar *fmt, ...)
 	gchar *text = g_strdup_vprintf(fmt, args);
 	va_end(args);
 
+	// Append text to remmina_log_file.log
+	remmina_log_file_append(text);
+
 #if GLIB_CHECK_VERSION(2,62,0)
 	GDateTime* tv = g_date_time_new_now_local();
 	gchar *isodate = g_date_time_format_iso8601(tv);
@@ -362,6 +392,9 @@ void _remmina_error(const gchar *fun, const gchar *fmt, ...)
 	text = g_strdup_vprintf(fmt, args);
 	va_end(args);
 
+	// Append text to remmina_log_file.log
+	remmina_log_file_append(text);
+
 	g_autofree gchar *buf = g_strconcat("(", fun, ") - ", text, NULL);
 	g_free(text);
 
@@ -389,6 +422,9 @@ void _remmina_critical(const gchar *fun, const gchar *fmt, ...)
 	text = g_strdup_vprintf(fmt, args);
 	va_end(args);
 
+	// Append text to remmina_log_file.log
+	remmina_log_file_append(text);
+
 	g_autofree gchar *buf = g_strconcat("(", fun, ") - ", text, NULL);
 	g_free(text);
 
